@@ -142,7 +142,9 @@ class PrizeListHandler(SevenBaseHandler):
             self.release_lock(queue_name, identifier)
             return self.reponse_json_error("NoMachine", "对不起，找不到该盲盒")
         specs_type = machine_info.specs_type
-        if specs_type == 5:
+        if specs_type == 3:
+            ran_num = random.randint(1, 3)
+        elif specs_type == 5:
             ran_num = random.randint(3, 5)
         elif specs_type == 6:
             ran_num = random.randint(3, 6)
@@ -278,7 +280,9 @@ class MinboxListHandler(SevenBaseHandler):
             self.release_lock(queue_name, identifier)
             return self.reponse_json_error("NoMachine", "对不起，找不到该盲盒")
         specs_type = machine_info.specs_type
-        if specs_type == 5:
+        if specs_type == 3:
+            ran_num = random.randint(1, 3)
+        elif specs_type == 5:
             ran_num = random.randint(3, 5)
         elif specs_type == 6:
             ran_num = random.randint(3, 6)
@@ -333,6 +337,7 @@ class MinboxListHandler(SevenBaseHandler):
         result_list = []
         redis_prize_dict = {}
         serial_no = 0
+        random.shuffle(act_prize_process_list)
         for act_prize in act_prize_process_list:
             update_result = act_prize_model.update_table("surplus=surplus-1", "id=%s AND surplus>0", params=[act_prize.id])
             # self.logging_link_info("update_result-" + str(update_result) + str(act_prize.id))
