@@ -249,7 +249,7 @@ class SyncPayOrderHandler(TopBaseHandler):
         if user_info.user_state == 0 and act_info.is_black == 1 and act_info.refund_count > 0:
             #退款的订单  子订单存在退款 记录一次
             # refund_order_data = [i for i in all_goods_order_list if [j for j in i if j["refund_status"] not in self.refund_status()]]
-            refund_order_data = [i for i in all_goods_order_list if i["refund_status"] not in self.refund_status()]
+            refund_order_data = [i for i in all_goods_order_list if i.get("refund_status") and i.get("refund_status") not in self.refund_status()]
             #如果不是黑用户 并且存在退款时间 代表黑用户解禁
             if user_info.relieve_date != '1900-01-01 00:00:00':
                 refund_order_data = [i for i in refund_order_data if TimeHelper.format_time_to_datetime(i['pay_time']) > TimeHelper.format_time_to_datetime(user_info.relieve_date)]
