@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2023-02-22 15:40:16
+@LastEditTime: 2023-09-18 13:49:25
 @LastEditors: HuangJianYi
 :description: 订单相关
 """
@@ -181,6 +181,7 @@ class PrizeRosterListHandler(SevenBaseHandler):
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         user_open_id = self.get_param("user_open_id")
+        prize_name = self.get_param("prize_name")
 
         condition = "act_id=%s"
         params = [act_id]
@@ -211,6 +212,9 @@ class PrizeRosterListHandler(SevenBaseHandler):
         if user_open_id:
             condition += " AND open_id=%s"
             params.append(user_open_id)
+        if prize_name:
+            condition += " AND prize_name=%s"
+            params.append(prize_name)
 
         page_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
@@ -246,6 +250,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         user_open_id = self.get_param("user_open_id")
+        prize_name = self.get_param("prize_name")
 
         condition = "act_id=%s"
         params = [act_id]
@@ -292,6 +297,9 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         if user_open_id:
             condition += " AND open_id=%s"
             params.append(user_open_id)
+        if prize_name:
+            condition += " AND prize_name=%s"
+            params.append(prize_name)
 
         prize_order_model = PrizeOrderModel(context=self)
         prize_roster_model = PrizeRosterModel(context=self)
@@ -575,7 +583,7 @@ class PrizeOrderImportHandler(SevenBaseHandler):
                     update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,modify_date=%s"
                     params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
                     prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
-                    prize_roster_model.update_table("order_status=1", "order_no=%s and act_id=%s", [order_no, act_id])
+                    prize_roster_model.update_table("order_status=1", "prize_order_no=%s and act_id=%s", [order_no, act_id])
         else:
             data = base64.decodebytes(content.encode())
             path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
@@ -614,7 +622,7 @@ class PrizeOrderImportHandler(SevenBaseHandler):
                     update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,modify_date=%s"
                     params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
                     prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
-                    prize_roster_model.update_table("order_status=1", "order_no=%s and act_id=%s", [order_no, act_id])
+                    prize_roster_model.update_table("order_status=1", "prize_order_no=%s and act_id=%s", [order_no, act_id])
             os.remove(path)
 
         return self.reponse_json_success()
